Struct sp_state_machine::BasicExternalities [−][src]
pub struct BasicExternalities { /* fields omitted */ }Expand description
Simple Map-based Externalities impl.
Implementations
Insert key/value
Consume self and returns inner storages
Execute the given closure f with the externalities set and initialized with storage.
Returns the result of the closure and updates storage with all changes.
Execute the given closure while self is set as externalities.
Returns the result of the given closure.
List of active extensions.
Register an extension.