CompactProof

Struct CompactProof 

pub struct CompactProof {
    pub encoded_nodes: Vec<Vec<u8>>,
}
Storage proof in compact form.

Fields

encoded_nodes: Vec<Vec<u8>>

Implementations

Source

impl CompactProof

pub fn iter_compact_encoded_nodes(&self) -> impl Iterator<Item = &[u8]>

Return an iterator on the compact encoded nodes.

pub fn to_storage_proof<H>( &self, expected_root: &<H as Hasher>::Out, ) -> Result<(StorageProof, <H as Hasher>::Out), Error<<H as Hasher>::Out, Error<<H as Hasher>::Out>>>
where H: Hasher,

Decode to a full storage_proof.

The decoded root is always checked against expected_root.

pub fn to_memory_db<H>( &self, expected_root: &<H as Hasher>::Out, ) -> Result<(MemoryDB<H, HashKey<H>, Vec<u8>>, <H as Hasher>::Out), Error<<H as Hasher>::Out, Error<<H as Hasher>::Out>>>
where H: Hasher,

Convert self into a MemoryDB.

expected_root is the expected root of this compact proof. The decoded root is always checked against it.

Returns the memory db and the root of the trie.