Type Definition sp_state_machine::DefaultError [−][src]
pub type DefaultError = String;Expand description
Default error type to use with state machine trie backend.
pub type DefaultError = String;Default error type to use with state machine trie backend.